PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/PCBoard.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Macros
PCBoard.hpp File Reference
`#include "Units.hpp"`
`#include "Geometry.hpp"`
`#include <map>`
`#include <vector>`
`#include <future>`
`#include <shared_mutex>`
`#include <atomic>`
`#include "LayoutArea.hpp"`
`#include "Layer.hpp"`
`#include "NavGrid.hpp"`
`#include "BVH.hpp"`

Go to the source code of this file.

## Data Structures
class | PCBoard

## Macros
#define | PCB_CHANGED_NAV_GRID (1 << 0)
#define | PCB_CHANGED_NAV_TRIS (1 << 1)
#define | PCB_CHANGED_ROUTES (1 << 2)
#define | PCB_CHANGED_COMPONENTS (1 << 3)
#define | PCB_CHANGED_PINS (1 << 4)
#define | PCB_CHANGED_NET_COLORS (1 << 5)
#define | PCB_CHANGED_OBJECTS (1 << 6)
#define | PCB_CHANGED_NEW_BOARD (1 << 15)
#define | PCB_CHANGED_OBJECTS_SET (PCB_CHANGED_OBJECTS | PCB_CHANGED_COMPONENTS | PCB_CHANGED_PINS | PCB_CHANGED_ROUTES)

## Macro Definition Documentation

## ◆ PCB_CHANGED_COMPONENTS

#define PCB_CHANGED_COMPONENTS (1 << 3)

## ◆ PCB_CHANGED_NAV_GRID

#define PCB_CHANGED_NAV_GRID (1 << 0)

## ◆ PCB_CHANGED_NAV_TRIS

#define PCB_CHANGED_NAV_TRIS (1 << 1)

## ◆ PCB_CHANGED_NET_COLORS

#define PCB_CHANGED_NET_COLORS (1 << 5)

## ◆ PCB_CHANGED_NEW_BOARD

#define PCB_CHANGED_NEW_BOARD (1 << 15)

## ◆ PCB_CHANGED_OBJECTS

#define PCB_CHANGED_OBJECTS (1 << 6)

## ◆ PCB_CHANGED_OBJECTS_SET

#define PCB_CHANGED_OBJECTS_SET (PCB_CHANGED_OBJECTS | PCB_CHANGED_COMPONENTS | PCB_CHANGED_PINS | PCB_CHANGED_ROUTES)

## ◆ PCB_CHANGED_PINS

#define PCB_CHANGED_PINS (1 << 4)

## ◆ PCB_CHANGED_ROUTES

#define PCB_CHANGED_ROUTES (1 << 2)